@@ -10,6 +10,8 @@ import re
 import sys
 
 from gunicorn._compat import unquote_to_wsgi_str
+from gunicorn.http.message import HEADER_RE
+from gunicorn.http.errors import InvalidHeader, InvalidHeaderName
 from gunicorn.six import string_types, binary_type, reraise
 from gunicorn import SERVER_SOFTWARE
 import gunicorn.util as util
@@ -28,6 +30,7 @@ except ImportError:
 BLKSIZE = 0x3FFFFFFF
 
 NORMALIZE_SPACE = re.compile(r'(?:\r\n)?[ \t]+')
+HEADER_VALUE_RE = re.compile(r'[\x00-\x1F\x7F]')
 
 log = logging.getLogger(__name__)
 
@@ -230,6 +233,8 @@ class Response(object):
             return True
         if self.response_length is not None or self.chunked:
             return False
+        if self.req.method == 'HEAD':
+            return False
         if self.status_code < 200 or self.status_code in (204, 304):
             return False
         return True
@@ -262,6 +267,13 @@ class Response(object):
         for name, value in headers:
             if not isinstance(name, string_types):
                 raise TypeError('%r is not a string' % name)
+
+            if HEADER_RE.search(name):
+                raise InvalidHeaderName('%r' % name)
+
+            if HEADER_VALUE_RE.search(value):
+                raise InvalidHeader('%r' % value)
+
             value = str(value).strip()
             lname = name.lower().strip()
             if lname == "content-length":
@@ -287,6 +299,9 @@ class Response(object):
             return False
         elif self.req.version <= (1, 0):
             return False
+        elif self.req.method == 'HEAD':
+            # Responses to a HEAD request MUST NOT contain a response body.
+            return False
         elif self.status_code in (204, 304):
             # Do not use chunked responses when the response is guaranteed to
             # not have a response body.
