@@ -5,5 +5,5 @@ request = {
     "headers": [
         ("TRANSFER-ENCODING", "chunked")
     ],
-    "body": "hello world"
-}
\ No newline at end of file
+    "body": b"hello world"
+}
